@@ -1,5 +1,22 @@
 import json
 from dotmap import DotMap
+import base64
+import hashlib
+import string
+
+
+def rand_string(seed, length, used=[]):
+	matches = True
+	while matches:
+		output = str(
+			base64.urlsafe_b64encode(
+				hashlib.md5(str(seed).encode('utf-8')).digest()),
+			'utf-8'
+		).rstrip(string.punctuation)[0:length-1]
+		seed = seed + "1"
+		matches = output in used
+
+	return output
 
 
 def credentials_loader(file):
